@@ -5,8 +5,8 @@
 ;; Author: Alexandr Timchenko <atimchenko92@gmail.com>
 ;; Maintainer: Alexandr Timchenko <atimchenko92@gmail.com>
 ;; URL: https://github.com/tmythicator/Lichess.el
-;; Package-Version: 20260121.249
-;; Package-Revision: ad69f7b43ac3
+;; Package-Version: 20260203.1027
+;; Package-Revision: 1dd8a25ede71
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: games, chess, lichess, api
 ;;
@@ -44,10 +44,13 @@
 (require 'lichess-tv)
 (require 'lichess-game)
 (require 'lichess-ai)
+(require 'lichess-challenge)
+(require 'lichess-challenge-list)
 (require 'lichess-fen)
 (require 'lichess-board)
+(require 'lichess-broadcast-list)
 (require 'lichess-board-tui)
-
+(require 'lichess-announce)
 
 (defgroup lichess nil
   "Lichess client."
@@ -64,12 +67,18 @@
   (interactive)
   (let* ((base-choices
           '(("Lichess TV: Show channels" . lichess-tv)
+            ("Lichess Broadcasts" . lichess-broadcast-list)
             ("Lichess: Watch game" . lichess-game-watch)
+            ("Lichess: Challenge a Friend" . lichess-challenge-user)
+            ("Lichess: List Challenges" . lichess-challenge-list)
             ("Lichess: Play against AI" . lichess-ai-challenge)
             ("Settings: Set Board Style" . lichess-set-style)))
          (debug-choices
           (if (locate-library "lichess-debug")
               '(("(Debug) Diagnose account" . lichess-debug-diagnose)
+                ("(Debug) Diagnose following"
+                 .
+                 lichess-debug-following)
                 ("(Debug) NDJSON Stream" . lichess-debug-game-stream)
                 ("(Debug) TV: JSON channels" . lichess-debug-tv)
                 ("(Debug) Render FEN position" . lichess-fen-show))
@@ -135,10 +144,10 @@ Warns if \"svg\" is selected but unavailable or missing assets."
              (fboundp 'lichess-fen-refresh))
         (funcall #'lichess-fen-refresh))
 
-       ((and (boundp 'lichess-game--current-idx)
-             lichess-game--current-idx
-             (fboundp 'lichess-game-refresh))
-        (funcall #'lichess-game-refresh))))))
+       ((and (boundp 'lichess-game--state)
+             lichess-game--state
+             (fboundp 'lichess-game-render))
+        (funcall #'lichess-game-render))))))
 
 (provide 'lichess)
 ;;; lichess.el ends here
